/****************************************************************************

Package:            de.mvcsys.epocutil
Class:              EButton

Task:               Button for EPOC applications

Author:             Jonathan Allin
Modified by:        Marcus von Cube

Credits:            Borrowed from "Professional Symbian Programming"
                    by Martin Tasker, Birmingham 2000

Updates:

Datum     Name  Vers.  Bemerkung
-----------------------------------------------------------------------------
26.04.03  MvC   1.0    package de.mvcsys.epocutil

****************************************************************************/

package de.mvcsys.epocutil;

import de.mvcsys.awtutil.GridPanel;
import java.awt.*;

/**
 *  Places a Button and Label in a GridPanel.
 *  Purpose is to make it simpler to
 *  display a keyboard shortcut below a button 
 */
public class EButton extends GridPanel
{
    public Button button;
    public Label shortcut;

    private static final Insets INSETS = new Insets( 0, 0, 0, 0 );
    public static final Font BUTTON_FONT =
            new Font( "Dialog", Font.BOLD, 12 );
    public static final Font SHORTCUT_FONT =
            new Font( "Dialog", Font.PLAIN, 12 );
    
    public EButton( String label, String shortCut )
    {
        constraints.insets = INSETS;
        constraints.fill = GridBagConstraints.HORIZONTAL;
        constraints.gridwidth = GridBagConstraints.REMAINDER;

        button = new Button( label );
        button.setFont( BUTTON_FONT );
        add( button, 0, 0 );

        shortcut = new Label( shortCut, Label.CENTER );
        shortcut.setFont( SHORTCUT_FONT );
        constraints.weighty = 2;
        add( shortcut, 0, 1 );
    }
}
